# lambdacloud

An unofficial python client for Lambda Lab's cloud computing platform.

## Installation

```
pip install lambdacloud
```

## Credits

This package is heavily inspired by [huggingface_hub](https://github.com/huggingface/huggingface_hub)
